# pydiverse.common

[![CI](https://github.com/pydiverse/pydiverse.common/actions/workflows/tests.yml/badge.svg)](https://github.com/pydiverse/pydiverse.common/actions/workflows/tests.yml)

A base package for different libraries in the pydiverse library collection.
This includes functionality like a type-system for tabular data (SQL and DataFrame).
This type-system is used for ensuring reliable operation of the pydiverse library
with various execution backends like Pandas, Polars, and various SQL dialects.

## Usage

pydiverse.common can either be installed via pypi with `pip install pydiverse-common` or via
conda-forge with `conda install pydiverse-common -c conda-forge`.
